#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_accesspoint_configuration_create
short_description: Resource module for Wireless Accesspoint Configuration Create
description:
  - Manage operation create of the resource Wireless Accesspoint Configuration Create.
  - User can configure multiple access points with required options using this intent API.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  adminStatus:
    description: Configure the access point's admin status. Set this parameter's value to "true" to enable it and "false"
      to disable it.
    type: bool
  apList:
    description: Wireless Accesspoint Configuration Create's apList.
    elements: dict
    suboptions:
      apName:
        description: The current host name of the access point.
        type: str
      apNameNew:
        description: The modified hostname of the access point.
        type: str
      macAddress:
        description: The ethernet MAC address of the access point.
        type: str
    type: list
  apMode:
    description: Configure the access point's mode for local/flexconnect mode, set "0"; for monitor mode, set "1"; for sniffer
      mode, set "4"; and for bridge/flex+bridge mode, set "5".
    type: int
  cleanAirSI24:
    description: Configure clean air status for radios that are in 2.4 Ghz band. Set this parameter's value to "true" to enable
      it and "false" to disable it.
    type: bool
  cleanAirSI5:
    description: Configure clean air status for radios that are in 5 Ghz band. Set this parameter's value to "true" to enable
      it and "false" to disable it.
    type: bool
  cleanAirSI6:
    description: Configure clean air status for radios that are in 6 Ghz band. Set this parameter's value to "true" to enable
      it and "false" to disable it.
    type: bool
  configureAdminStatus:
    description: To change the access point's admin status, set this parameter's value to "true".
    type: bool
  configureApMode:
    description: To change the access point's mode, set this parameter's value to "true".
    type: bool
  configureCleanAirSI24Ghz:
    description: To change the clean air status for radios that are in 2.4 Ghz band, set this parameter's value to "true".
    type: bool
  configureCleanAirSI5Ghz:
    description: To change the clean air status for radios that are in 5 Ghz band, set this parameter's value to "true".
    type: bool
  configureCleanAirSI6Ghz:
    description: To change the clean air status for radios that are in 6 Ghz band, set this parameter's value to "true".
    type: bool
  configureFailoverPriority:
    description: To change the access point's failover priority, set this parameter's value to "true".
    type: bool
  configureHAController:
    description: To change the access point's HA controller, set this parameter's value to "true".
    type: bool
  configureLedBrightnessLevel:
    description: To change the access point's LED brightness level, set this parameter's value to "true".
    type: bool
  configureLedStatus:
    description: To change the access point's LED status, set this parameter's value to "true".
    type: bool
  configureLocation:
    description: To change the access point's location, set this parameter's value to "true".
    type: bool
  failoverPriority:
    description: Configure the acess point's failover priority for low, set "1"; for medium, set "2"; for high, set "3"; and
      for critical, set "4".
    type: int
  isAssignedSiteAsLocation:
    description: To configure the access point's location as the site assigned to the access point, set this parameter's value
      to "true".
    type: bool
  ledBrightnessLevel:
    description: Configure the access point's LED brightness level by setting a value between 1 and 8.
    type: int
  ledStatus:
    description: Configure the access point's LED status. Set "true" to enable its status and "false" to disable it.
    type: bool
  location:
    description: Configure the access point's location.
    type: str
  primaryControllerName:
    description: Configure the hostname for an access point's primary controller.
    type: str
  primaryIpAddress:
    description: Wireless Accesspoint Configuration Create's primaryIpAddress.
    suboptions:
      address:
        description: Configure the IP address for an access point's primary controller.
        type: str
    type: dict
  radioConfigurations:
    description: Wireless Accesspoint Configuration Create's radioConfigurations.
    elements: dict
    suboptions:
      adminStatus:
        description: Configure the admin status on the specified radio for an access point. Set this parameter's value to
          "true" to enable it and "false" to disable it.
        type: bool
      antennaCableName:
        description: Configure the antenna cable name on the specified radio for an access point. If cable loss needs to be
          configured, set this parameter's value to "other".
        type: str
      antennaGain:
        description: Configure the antenna gain on the specified radio for an access point by setting a decimal value (in
          dBi). To configure "antennaGain", set "antennaPatternName" value to "other". The External Antenna Gain value will
          be applied in 0.5 dBi increments on the controller. Therefore, the value entered will be multiplied by 2 to configure
          the absolute gain value. AntennaGain should be in range of 0-20.
        type: int
      antennaPatternName:
        description: Specify the antenna name on the specified radio for an access point. The antenna name is used to calculate
          the gain on the radio slot.
        type: str
      cableLoss:
        description: Configure the cable loss on the specified radio for an access point by setting a decimal value (in dBi).
        type: float
      channelAssignmentMode:
        description: Configure the channel assignment mode on the specified radio for an access point for global mode, set
          "1"; and for custom mode, set "2".
        type: int
      channelNumber:
        description: Configure the channel number on the specified radio for an access point.
        type: int
      channelWidth:
        description: Configure the channel width on the specified radio for an access point for 20 MHz, set "3"; for 40 MHz,
          set "4"; for 80 MHz, set "5"; for 160 MHz, set "6", and for 320 MHz, set "7".
        type: int
      configureAdminStatus:
        description: To change the admin status on the specified radio for an access point, set this parameter's value to
          "true".
        type: bool
      configureAntennaCable:
        description: To change the antenna cable name on the specified radio for an access point, set this parameter's value
          to "true".
        type: bool
      configureAntennaPatternName:
        description: To change the antenna gain on the specified radio for an access point, set the value for this parameter
          to "true".
        type: bool
      configureChannel:
        description: To change the channel on the specified radio for an access point, set this parameter's value to "true".
        type: bool
      configureChannelWidth:
        description: To change the channel width on the specified radio for an access point, set this parameter's value to
          "true".
        type: bool
      configurePower:
        description: To change the power assignment mode on the specified radio for an access point, set this parameter's
          value to "true".
        type: bool
      configureRadioRoleAssignment:
        description: To change the radio role on the specified radio for an access point, set this parameter's value to "true".
        type: bool
      powerAssignmentMode:
        description: Configure the power assignment mode on the specified radio for an access point for global mode, set "1";
          and for custom mode, set "2".
        type: int
      powerlevel:
        description: Configure the power level on the specified radio for an access point by setting a value between 1 and
          8.
        type: int
      radioBand:
        description: Configure the band on the specified radio for an access point for 2.4 GHz, set "RADIO24"; for 5 GHz,
          set "RADIO5"; for 6 GHz, set "RADIO6". Any other string is invalid, including empty string.
        type: str
      radioRoleAssignment:
        description: Configure only one of the following roles on the specified radio for an access point as "AUTO", "SERVING",
          or "MONITOR". Any other string is invalid, including empty string.
        type: str
      radioType:
        description: Configure an access point's radio band for 2.4 GHz, set "1"; for 5 GHz, set "2"; for XOR, set "3"; and
          for 6 GHz, set "6".
        type: int
    type: list
  secondaryControllerName:
    description: Configure the hostname for an access point's secondary controller.
    type: str
  secondaryIpAddress:
    description: Wireless Accesspoint Configuration Create's secondaryIpAddress.
    suboptions:
      address:
        description: Configure the IP address for an access point's secondary controller.
        type: str
    type: dict
  tertiaryControllerName:
    description: Configure the hostname for an access point's tertiary controller.
    type: str
  tertiaryIpAddress:
    description: Wireless Accesspoint Configuration Create's tertiaryIpAddress.
    suboptions:
      address:
        description: Configure the IP address for an access point's tertiary controller.
        type: str
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless ConfigureAccessPointsV2
    description: Complete reference of the ConfigureAccessPointsV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!configure-access-points-v-2
notes:
  - SDK Method used are
    wireless.Wireless.configure_access_points_v2,
  - Paths used are
    post /dna/intent/api/v2/wireless/accesspoint-configuration,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_accesspoint_configuration_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    adminStatus: true
    apList:
      - apName: string
        apNameNew: string
        macAddress: string
    apMode: 0
    cleanAirSI24: true
    cleanAirSI5: true
    cleanAirSI6: true
    configureAdminStatus: true
    configureApMode: true
    configureCleanAirSI24Ghz: true
    configureCleanAirSI5Ghz: true
    configureCleanAirSI6Ghz: true
    configureFailoverPriority: true
    configureHAController: true
    configureLedBrightnessLevel: true
    configureLedStatus: true
    configureLocation: true
    failoverPriority: 0
    isAssignedSiteAsLocation: true
    ledBrightnessLevel: 0
    ledStatus: true
    location: string
    primaryControllerName: string
    primaryIpAddress:
      address: string
    radioConfigurations:
      - adminStatus: true
        antennaCableName: string
        antennaGain: 0
        antennaPatternName: string
        cableLoss: 0
        channelAssignmentMode: 0
        channelNumber: 0
        channelWidth: 0
        configureAdminStatus: true
        configureAntennaCable: true
        configureAntennaPatternName: true
        configureChannel: true
        configureChannelWidth: true
        configurePower: true
        configureRadioRoleAssignment: true
        powerAssignmentMode: 0
        powerlevel: 0
        radioBand: string
        radioRoleAssignment: string
        radioType: 0
    secondaryControllerName: string
    secondaryIpAddress:
      address: string
    tertiaryControllerName: string
    tertiaryIpAddress:
      address: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ipam_server_setting
short_description: Resource module for Ipam Server Setting
description:
  - Manage operations create, update and delete of the resource Ipam Server Setting. - > Creates configuration details of
    the external IPAM server. You should only create one external IPAM server; delete any existing external server before
    creating a new one. Please note, the certificate of the external IPAM server must be trusted by the Catalyst Center server
    before using this API. Trusted certificates can be uploaded using 'Import Trusted Certificate' intent API.
  - Deletes configuration details of the external IPAM server.
  - Updates configuration details of the external IPAM server.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  password:
    description: The password for the external IPAM server login username.
    type: str
  provider:
    description: Type of external IPAM. Can be either INFOBLOX, BLUECAT or GENERIC.
    type: str
  serverName:
    description: A descriptive name of this external server, used for identification purposes.
    type: str
  serverUrl:
    description: The URL of this external server.
    type: str
  syncView:
    description: Synchronize the IP pools from the local IPAM to this external server.
    type: bool
  userName:
    description: The external IPAM server login username.
    type: str
  view:
    description: The view under which pools are created in the external IPAM server.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for System Settings CreatesConfigurationDetailsOfTheExternalIPAMServer
    description: Complete reference of the CreatesConfigurationDetailsOfTheExternalIPAMServer API.
    link: https://developer.cisco.com/docs/dna-center/#!creates-configuration-details-of-the-external-ipam-server
  - name: Cisco DNA Center documentation for System Settings DeletesConfigurationDetailsOfTheExternalIPAMServer
    description: Complete reference of the DeletesConfigurationDetailsOfTheExternalIPAMServer API.
    link: https://developer.cisco.com/docs/dna-center/#!deletes-configuration-details-of-the-external-ipam-server
  - name: Cisco DNA Center documentation for System Settings UpdatesConfigurationDetailsOfTheExternalIPAMServer
    description: Complete reference of the UpdatesConfigurationDetailsOfTheExternalIPAMServer API.
    link: https://developer.cisco.com/docs/dna-center/#!updates-configuration-details-of-the-external-ipam-server
notes:
  - SDK Method used are
    system_settings.SystemSettings.creates_configuration_details_of_the_external_ip_a_m_server,
    system_settings.SystemSettings.deletes_configuration_details_of_the_external_ip_a_m_server,
    system_settings.SystemSettings.updates_configuration_details_of_the_external_ip_a_m_server,
  - Paths used are
    post /dna/intent/api/v1/ipam/serverSetting,
    delete /dna/intent/api/v1/ipam/serverSetting,
    put /dna/intent/api/v1/ipam/serverSetting,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.ipam_server_setting:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
- name: Create
  cisco.dnac.ipam_server_setting:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    password: string
    provider: string
    serverName: string
    serverUrl: string
    syncView: true
    userName: string
    view: string
- name: Update all
  cisco.dnac.ipam_server_setting:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    password: string
    serverName: string
    serverUrl: string
    syncView: true
    userName: string
    view: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: software_management_executions_info
short_description: Information module for Software Management Executions
description:
  - Get Software Management Executions by id.
  - This api is used to get execution status and task details of a specific software management workflows.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. The id of the execution detail to be retrieved.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for System Software Upgrade GetSoftwareManagementExecutionDetails
    description: Complete reference of the GetSoftwareManagementExecutionDetails API.
    link: https://developer.cisco.com/docs/dna-center/#!get-software-management-execution-details
notes:
  - SDK Method used are
    system_software_upgrade.SystemSoftwareUpgrade.get_software_management_execution_details,
  - Paths used are
    get /dna/system/api/v1/softwareManagementExecutions/{id},
"""

EXAMPLES = r"""
---
- name: Get Software Management Executions by id
  cisco.dnac.software_management_executions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "completedPercentage": 0,
        "createdBy": "string",
        "duration": 0,
        "endDate": "string",
        "errorCode": "string",
        "errorMessage": "string",
        "isForceUpdate": true,
        "jobType": "string",
        "localReleaseId": "string",
        "optionalPackages": [
          "string"
        ],
        "releaseDisplayName": "string",
        "releaseDisplayVersion": "string",
        "releaseName": "string",
        "releaseVersion": "string",
        "startDate": "string",
        "status": "string",
        "systemErrorMessage": "string",
        "tasks": [
          {
            "id": "string",
            "endDate": "string",
            "errorCode": "string",
            "message": "string",
            "startDate": "string",
            "status": "string",
            "systemErrorMessage": "string",
            "taskName": "string"
          }
        ],
        "updateMessage": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: feature_templates_wireless_advanced_ssid_configurations
short_description: Resource module for Feature Templates Wireless Advanced Ssid Configurations
description:
  - Manage operations create, update and delete of the resource Feature Templates Wireless Advanced Ssid Configurations.
  - This API allows users to create a Advanced SSID configuration feature template.
  - This API allows users to delete a specific Advanced SSID configuration feature template by Id.
  - This API allows users to update the details of a specific Advanced SSID configuration feature template by ID.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  designName:
    description: Design Name.
    type: str
  featureAttributes:
    description: Feature Templates Wireless Advanced Ssid Configurations's featureAttributes.
    suboptions:
      advertisePCAnalyticsSupport:
        description: Advertise PC Analytics Support.
        type: bool
      advertiseSupport:
        description: Advertise Support.
        type: bool
      aironetIESupport:
        description: Aironet IE Enable.
        type: bool
      callSnooping:
        description: Call Snooping.
        type: bool
      deferPriority0:
        description: Defer Priority0.
        type: bool
      deferPriority1:
        description: Defer Priority1.
        type: bool
      deferPriority2:
        description: Defer Priority2.
        type: bool
      deferPriority3:
        description: Defer Priority3.
        type: bool
      deferPriority4:
        description: Defer Priority4.
        type: bool
      deferPriority5:
        description: Defer Priority5.
        type: bool
      deferPriority6:
        description: Defer Priority6.
        type: bool
      deferPriority7:
        description: Defer Priority7.
        type: bool
      dhcpOpt82RemoteIDSubOption:
        description: DHCP Option82 Remote ID suboption.
        type: bool
      dhcpRequired:
        description: Dynamic Host Configuration Protocol (DHCP) Required.
        type: bool
      dhcpServer:
        description: Dynamic Host Configuration Protocol (DHCP) Server.
        type: str
      dot11ax:
        description: 802.11ax Status.
        type: bool
      dot11vBSSMaxIdleProtected:
        description: Dot11v Basic Service Set (Bss) Max Idle Protected.
        type: bool
      downlinkMuMimo:
        description: Downlink multi-user, multiple input, multiple output (MU-MIMO).
        type: bool
      downlinkOfdma:
        description: Downlink orthogonal frequency-division multiple access (OFDMA).
        type: bool
      dtimPeriod24GHz:
        description: Delivery Traffic Indication Map (DTIM) Period 2.4GhZ Band (1-255).
        type: int
      dtimPeriod5GHz:
        description: Delivery Traffic Indication Map (DTIM) Period 5GhZ Band (1-255).
        type: int
      dualBandNeighborList:
        description: Neighbor List Dual Band.
        type: bool
      fastTransitionReassociationTimeout:
        description: Reassociation Timeout time.
        type: int
      fastlaneASR:
        description: Fastlane Advanced Scheduling Request (ASR).
        type: bool
      flexLocalAuth:
        description: FlexConnect Local Authentication.
        type: bool
      idleThreshold:
        description: Idle threshold.
        type: int
      ipMacBinding:
        description: IP Mac Binding.
        type: bool
      ipSourceGuard:
        description: IP Source Guard.
        type: bool
      loadBalancing:
        description: Load Balance Enable.
        type: bool
      mDNSMode:
        description: Multicast Domain Name Services (mDNS) Mode.
        type: str
      maxClients:
        description: For physical 9800 series controllers, valid ranges are - 0-5000 for 9800-L series - 0-32000 for 9800-40
          series - 0-64000 for 9800-80 series For 9800-CL series controllers, valid ranges are - 0-10000 for Small (S) VM
          - 0-32000 for Medium (M) VM - 0-64000 for Large (L) VM For Embedded Wireless Controller and Mobility Express, the
          valid range is 0-2000. For the 9300 platform, the valid range is 0-4000. For the AireOS platform, valid ranges are
          - 0-3000 for 3500 series - 0-20000 for 5500 series - 0-64000 for 8500 series.
        type: int
      maxClientsPerAp:
        description: Max client Per AP Per WLAN.
        type: int
      maxClientsPerRadio:
        description: Max client Per AP radio Per WLAN.
        type: int
      mediaStreamMulticastDirect:
        description: Media Stream Multicast Direct.
        type: bool
      muMimo11ac:
        description: Multi-user, multiple input, multiple output (Mu Mimo) 11ac.
        type: bool
      multicastBuffer:
        description: Multicast Buffer Enabled.
        type: bool
      multicastBufferValue:
        description: Multicast Buffer Value.
        type: int
      opportunisticKeyCaching:
        description: Opportunistic Key Caching.
        type: bool
      passiveClient:
        description: Passive Client.
        type: bool
      peer2peerblocking:
        description: Peer-to-Peer Blocking.
        type: str
      predictionOptimization:
        description: Assisted Roaming Prediction Optimization.
        type: bool
      radiusNacState:
        description: Network Admission Control(NAC-Radius).
        type: bool
      scanDeferTime:
        description: Scan Defer Time.
        type: int
      sendBeaconOnAssociation:
        description: Client Scan Report On Association.
        type: bool
      sendBeaconOnRoam:
        description: Client Scan Report On Roam.
        type: bool
      sendDisassociate:
        description: Send Disassociate.
        type: bool
      sent486Busy:
        description: Send 486 Busy.
        type: bool
      shareDataWithClient:
        description: Share Data with Client.
        type: bool
      targetWakeupTime:
        description: BSS Target Wake Up Time.
        type: bool
      universalAPAdmin:
        description: Universal Admin.
        type: bool
      uplinkMuMimo:
        description: Uplink multi-user, multiple input, multiple output (MU-MIMO).
        type: bool
      uplinkOfdma:
        description: Uplink orthogonal frequency-division multiple access (OFDMA).
        type: bool
      vlanCentralSwitching:
        description: VLAN Central Switching.
        type: bool
      wifiAllianceAgileMultiband:
        description: Wi-Fi Alliance Agile Multiband.
        type: bool
      wifiToCellularSteering:
        description: Wifi To Cellular Steering.
        type: bool
      wmmPolicy:
        description: Wi-Fi Multimedia (WMM) Policy.
        type: str
    type: dict
  id:
    description: Id path parameter. Advanced SSID Configuration Feature Template Id.
    type: str
  unlockedAttributes:
    description: Attributes unlocked in design can be changed at device provision time. `Note ` unlockedAttributes can only
      contain the attributes defined under featureAttributes.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless CreateAdvancedSSIDConfigurationFeatureTemplate
    description: Complete reference of the CreateAdvancedSSIDConfigurationFeatureTemplate API.
    link: https://developer.cisco.com/docs/dna-center/#!create-advanced-ssid-configuration-feature-template
  - name: Cisco DNA Center documentation for Wireless DeleteAdvancedSSIDConfigurationFeatureTemplate
    description: Complete reference of the DeleteAdvancedSSIDConfigurationFeatureTemplate API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-advanced-ssid-configuration-feature-template
  - name: Cisco DNA Center documentation for Wireless UpdateAdvancedSSIDConfigurationFeatureTemplate
    description: Complete reference of the UpdateAdvancedSSIDConfigurationFeatureTemplate API.
    link: https://developer.cisco.com/docs/dna-center/#!update-advanced-ssid-configuration-feature-template
notes:
  - SDK Method used are
    wireless.Wireless.create_advanced_ssid_configuration_feature_template,
    wireless.Wireless.delete_advanced_ssid_configuration_feature_template,
    wireless.Wireless.update_advanced_ssid_configuration_feature_template,
  - Paths used are
    post /dna/intent/api/v1/featureTemplates/wireless/advancedSSIDConfigurations,
    delete /dna/intent/api/v1/featureTemplates/wireless/advancedSSIDConfigurations/{id},
    put /dna/intent/api/v1/featureTemplates/wireless/advancedSSIDConfigurations/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.feature_templates_wireless_advanced_ssid_configurations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    designName: string
    featureAttributes:
      advertisePCAnalyticsSupport: true
      advertiseSupport: true
      aironetIESupport: true
      callSnooping: true
      deferPriority0: true
      deferPriority1: true
      deferPriority2: true
      deferPriority3: true
      deferPriority4: true
      deferPriority5: true
      deferPriority6: true
      deferPriority7: true
      dhcpOpt82RemoteIDSubOption: true
      dhcpRequired: true
      dhcpServer: string
      dot11ax: true
      dot11vBSSMaxIdleProtected: true
      downlinkMuMimo: true
      downlinkOfdma: true
      dtimPeriod24GHz: 0
      dtimPeriod5GHz: 0
      dualBandNeighborList: true
      fastTransitionReassociationTimeout: 0
      fastlaneASR: true
      flexLocalAuth: true
      idleThreshold: 0
      ipMacBinding: true
      ipSourceGuard: true
      loadBalancing: true
      mDNSMode: string
      maxClients: 0
      maxClientsPerAp: 0
      maxClientsPerRadio: 0
      mediaStreamMulticastDirect: true
      muMimo11ac: true
      multicastBuffer: true
      multicastBufferValue: 0
      opportunisticKeyCaching: true
      passiveClient: true
      peer2peerblocking: string
      predictionOptimization: true
      radiusNacState: true
      scanDeferTime: 0
      sendBeaconOnAssociation: true
      sendBeaconOnRoam: true
      sendDisassociate: true
      sent486Busy: true
      shareDataWithClient: true
      targetWakeupTime: true
      universalAPAdmin: true
      uplinkMuMimo: true
      uplinkOfdma: true
      vlanCentralSwitching: true
      wifiAllianceAgileMultiband: true
      wifiToCellularSteering: true
      wmmPolicy: string
    unlockedAttributes:
      - string
- name: Delete by id
  cisco.dnac.feature_templates_wireless_advanced_ssid_configurations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.feature_templates_wireless_advanced_ssid_configurations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    designName: string
    featureAttributes:
      advertisePCAnalyticsSupport: true
      advertiseSupport: true
      aironetIESupport: true
      callSnooping: true
      deferPriority0: true
      deferPriority1: true
      deferPriority2: true
      deferPriority3: true
      deferPriority4: true
      deferPriority5: true
      deferPriority6: true
      deferPriority7: true
      dhcpOpt82RemoteIDSubOption: true
      dhcpRequired: true
      dhcpServer: string
      dot11ax: true
      dot11vBSSMaxIdleProtected: true
      downlinkMuMimo: true
      downlinkOfdma: true
      dtimPeriod24GHz: 0
      dtimPeriod5GHz: 0
      dualBandNeighborList: true
      fastTransitionReassociationTimeout: 0
      fastlaneASR: true
      flexLocalAuth: true
      idleThreshold: 0
      ipMacBinding: true
      ipSourceGuard: true
      loadBalancing: true
      mDNSMode: string
      maxClients: 0
      maxClientsPerAp: 0
      maxClientsPerRadio: 0
      mediaStreamMulticastDirect: true
      muMimo11ac: true
      multicastBuffer: true
      multicastBufferValue: 0
      opportunisticKeyCaching: true
      passiveClient: true
      peer2peerblocking: string
      predictionOptimization: true
      radiusNacState: true
      scanDeferTime: 0
      sendBeaconOnAssociation: true
      sendBeaconOnRoam: true
      sendDisassociate: true
      sent486Busy: true
      shareDataWithClient: true
      targetWakeupTime: true
      universalAPAdmin: true
      uplinkMuMimo: true
      uplinkOfdma: true
      vlanCentralSwitching: true
      wifiAllianceAgileMultiband: true
      wifiToCellularSteering: true
      wmmPolicy: string
    id: string
    unlockedAttributes:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""
